==============
geocube README
==============

Tool to convert geopandas vector data into rasterized xarray data.

Documentation: https://corteva.github.io/geocube


.. image:: https://badges.gitter.im/corteva--geocube/community.svg
   :alt: Join the chat at https://gitter.im/corteva--geocube/community
   :target: https://gitter.im/corteva--geocube/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge

.. image:: https://img.shields.io/badge/license-BSD%203--Clause-yellow.svg
    :target: https://github.com/corteva/geocube/blob/master/LICENSE

.. image:: https://img.shields.io/pypi/v/geocube.svg
    :target: https://pypi.python.org/pypi/geocube

.. image:: https://img.shields.io/conda/vn/conda-forge/geocube.svg
    :target: https://anaconda.org/conda-forge/geocube

.. image:: https://travis-ci.com/corteva/geocube.svg?branch=master
    :target: https://travis-ci.com/corteva/geocube

.. image:: https://ci.appveyor.com/api/projects/status/bjxhlbt5tjsonwo8/branch/master?svg=true
    :target: https://ci.appveyor.com/project/snowman2/geocube

.. image:: https://coveralls.io/repos/github/corteva/geocube/badge.svg?branch=master
    :target: https://coveralls.io/github/corteva/geocube?branch=master


Credits
-------

This package was originally templated with with Cookiecutter_.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
